
.portletGallery .portletItem {
	text-align:center;
}

.portletGallery .portletItem a {
	display:block;
	margin:5px 0;
}

.photoAlbumEntry a,
.photoAlbumEntry a:focus {
    margin:16px auto 0 !important;
}